API Documentation
=================

Comprehensive reference material for every public API exposed by
`kazoo` is available within this chapter. The API documentation is
organized alphabetically by module name.

.. toctree::
   :maxdepth: 1

   api/client
   api/exceptions
   api/handlers/gevent
   api/handlers/threading
   api/handlers/utils
   api/interfaces
   api/protocol/states
   api/recipe/barrier
   api/recipe/cache
   api/recipe/counter
   api/recipe/election
   api/recipe/lease
   api/recipe/lock
   api/recipe/partitioner
   api/recipe/party
   api/recipe/queue
   api/recipe/watchers
   api/retry
   api/security
   api/testing
